---
name: Implementacja zapytania POST
about: Pomóż w implementacji metody
title: "[IMPLEMENTACJA POST]"
labels: enhancement
assignees: Asapros

---

**Jaka metoda nie jest zaimplementowana?**
nazwa-klasy.nazwa-metody

**Wymagania w NotImplementedError**
Zakładając, że przychodzisz tutaj przez wyjątek NotImplementedError, wypisz tutaj informacje, o których mówił (będzie to wymagało wykonanie zapytania na własną rękę)

**Dodatkowe informacje**
Możesz tutaj coś dodać od siebie
